#Instalation of any library
library(car)          # provides a set of useful functions for ANOVA designs and Regression Models;
library(lattice)      # provides some graphical enhancements compared to traditional R graphics, as well as multivariate displays capabilities;
library(lme4)         # the newer and enhanced version of the nlme package, for which additional data structure are available (nested or hierarchical model,. . . );
library(nlme)         # for handling mixed-effects models;
library(lsmeans)  
library(pbkrtest)
library(gmodels)

# Define directory
setwd("D:/Vyuka/NEX/2018/10_Random_factors_mixed_models/")

planks <- read.table("Data/planks.txt",header=TRUE,sep=",")
head(planks)
planks$plank  <-factor(planks$plank)
planks$width  <-factor(planks$width)
planks$depth  <-factor(planks$depth)
attach(planks)

with(planks, interaction.plot(width,plank,humidity,legend=F))
with(planks, interaction.plot(depth,plank,humidity,legend=F))
with(planks, interaction.plot(width,depth,humidity,legend=F))
with(planks, interaction.plot(depth,width,humidity,legend=F))

model1<-lme(humidity~depth*width,random=~1|plank,data=planks)
anova(model1)
summary(model1)

model2<-lme(humidity~depth+width,random=~1|plank,data=planks)
anova_model2 = anova(model2)
anova(model2)
summary(model2)

model2_lmer<-lmer(humidity~depth+width+(1|plank),data=planks)
anova(model2_lmer)
summary(model2_lmer)


lsmeans(model2_lmer, pairwise~depth, adjust="tukey") 


#Post hoc analysis
#par(mfrow=c(2,2))
#plot(model2)

conMat1<-matrix(0, 5, 7)
#colnames(conMat1) <- names(coef(model2))
conMat1[1,]<-c(1,0,0,0,0,1/3,1/3)
conMat1[2,]<-c(1,1,0,0,0,1/3,1/3)
conMat1[3,]<-c(1,0,1,0,0,1/3,1/3)
conMat1[4,]<-c(1,0,0,1,0,1/3,1/3)
conMat1[5,]<-c(1,0,0,0,1,1/3,1/3)
conMat1


estMat1<-estimable(model2,conMat1,conf.int=0.95)
estMat1[, c(1, 2, 6, 7)]
lsmeans(model2, pairwise~depth) 



conMat2<-matrix(0, 10, 7)
rownames(conMat2) <- c("1-3","1-5","1-7","1-9","3-5","3-7","3-9","5-7","5-9","7-9")
#colnames(conMat2) <- names(coef(model2))
conMat2[1,]<-c(0,1,0,0,0,0,0)
conMat2[2,]<-c(0,0,1,0,0,0,0)
conMat2[3,]<-c(0,0,0,1,0,0,0)
conMat2[4,]<-c(0,0,0,0,1,0,0)
conMat2[5,]<-c(0,1,-1,0,0,0,0)
conMat2[6,]<-c(0,1,0,-1,0,0,0)
conMat2[7,]<-c(0,1,0,0,-1,0,0)
conMat2[8,]<-c(0,0,1,-1,0,0,0)
conMat2[9,]<-c(0,0,1,0,-1,0,0)
conMat2[10,]<-c(0,0,0,1,-1,0,0)

estMat2<-estimable(model2,conMat2,conf.int=0.95)
estMat2[, c(1, 2, 6, 7, 5)]

p.adjust(estMat2[, c(5)], method = c("bon"))


tukey.adjust<-function(estMat,conf.int)
{
  noCI<-F
  if (missing(conf.int)) {noCI<-T}
n1<-nrow(estMat)
n<-(1+sqrt(1+8*n1))/2
confWidth<-rep(0,n1)
pValue<-rep(0,n1)
for (i in 1:n1)
{
  dev<-estMat[i,2]/sqrt(2)
  if (!noCI) {confWidth[i]<-qtukey(conf.int,n,estMat[i,3])*dev}
  pValue[i]<-ptukey(abs(estMat[i,1])/dev,n,estMat[i,3],lower.tail=F)
}
dimNames<-attr(estMat,"dimnames")
dimNames[[2]]<-c("Adj Pr(>|t|)","Adj Lower CI","Adj Upper CI")
pdiffMat<-matrix(0,n1,3,dimnames=dimNames)
pdiffMat[,2]<-estMat[,1]-confWidth
pdiffMat[,3]<-estMat[,1]+confWidth
pdiffMat[,1]<-pValue
if (noCI) {return(pdiffMat[,1])}
else {return(pdiffMat)}
}

tukey.adjust(estMat2[, c(1, 2, 4)])

cbind(estMat2[, c(1, 2)], tukey.adjust(estMat2[, c(1, 2, 4)],conf.int = 0.95))



#bad - with fixed :(
aov_model2 = aov(humidity~depth+width,data=planks)  #,random=~1|plank,
Tukey_results = TukeyHSD(aov_model2,which="depth") 

# with mixed
model2<-lme(humidity~depth+width,random=~1|plank,data=planks, method="REML")
anova_model2 = anova(model2)
anova(model2)


model3<-lmer(humidity~depth+width+(1|plank),data=planks)
summary(model3)

library(lsmeans)  
library(pbkrtest)
lsmeans(model3, pairwise~depth, adjust="tukey") 

#compare to 
cbind(estMat2[, c(1, 2)], tukey.adjust(estMat2[, c(1, 2, 4)],conf.int = 0.95))




model1 <- lm(humidity~depth+plank+width)
summary(model1)
anova(model1)

res1 <- studres(model1)

par(mfrow=c(1,2))
truehist(res1,col=0)
x<-(-30:30)/10
y<-dnorm(x,0,1)
lines(x,y)


qqnorm(res1)
abline(0,1)
par(mfrow=c(1,1))

par(mfrow=c(2,2))
with(planks, plot(predict(model1),res1))
with(planks, plot(plank,res1))
with(planks, plot(width,res1))
with(planks, plot(depth,res1))
par(mfrow=c(1,1))

shapiro.test(res1)
detach(planks)

#The logarithm-transformed response is added to the planks data frame as the new variable loghum
planks$loghum <- log(planks$humidity)
attach(planks)
head(planks)




#The model for the logarithm-transformed response
model2 <- lm(loghum~depth+plank+width)
library(MASS)
res2   <- studres(model2)
#Diagnostic plots for model2 are constructed in the manner as for model1
par(mfrow=c(1,2))
truehist(res2,col=0)
qqnorm(res2)
abline(0,1)

shapiro.test(res2)

par(mfrow=c(2,2))
with(planks, plot(predict(model2),res2))
with(planks, plot(plank,res2))
with(planks, plot(width,res2))
with(planks, plot(depth,res2))
par(mfrow=c(1,1))


#Test of overall effects/model reduction for transformed data

model3 <- lm(loghum ~ depth*plank + depth*width + plank*width, data = planks)
anova(model3)

const   <- rep(1, length(planks$loghum))
model4  <-lme(loghum ~ depth*width,random=list(const=pdBlocked(list(~plank-1,~depth:plank-1,~plank:width-1),pdClass="pdIdent")))
anova(model4)

model4b  <-lme(humidity ~ depth+width+width:depth,random= ~1|plank)
anova(model4b)

model4c  <-lme(humidity ~ depth+width,random= ~1|plank)
anova(model4c)


unique(VarCorr(model4c)[, 1])

model5<-lme(loghum ~ depth:width-1, random=list(const=pdBlocked(list(~plank-1,~depth:plank-1,~plank:width-1),
            pdClass="pdIdent")),data=planks)
exp(fixed.effects(model5))

depth<-rep(c(1,3,5,7,9),3)
width<-rep(c(1,2,3),c(5,5,5))
interaction.plot(depth, width, exp(fixed.effects(model5)))


#names(fixed.effects(model5))
#names(coef(model5))

# Comparisons of depth for width=1.
conMat<-matrix(0,10,15)
#dimNames<-list(c("1-3","1-5","1-7","1-9","3-5","3-7","3-9","5-7","5-9","7-9"),rep("",15))
#conMat<-matrix(0,10,15,dimnames=dimNames)

conMat[1,]<-c(1,-1,0,0,0,0,0,0,0,0,0,0,0,0,0)
conMat[2,]<-c(1,0,-1,0,0,0,0,0,0,0,0,0,0,0,0)
conMat[3,]<-c(1,0,0,-1,0,0,0,0,0,0,0,0,0,0,0)
conMat[4,]<-c(1,0,0,0,-1,0,0,0,0,0,0,0,0,0,0)
conMat[5,]<-c(0,1,-1,0,0,0,0,0,0,0,0,0,0,0,0)
conMat[6,]<-c(0,1,0,-1,0,0,0,0,0,0,0,0,0,0,0)
conMat[7,]<-c(0,1,0,0,-1,0,0,0,0,0,0,0,0,0,0)
conMat[8,]<-c(0,0,1,-1,0,0,0,0,0,0,0,0,0,0,0)
conMat[9,]<-c(0,0,1,0,-1,0,0,0,0,0,0,0,0,0,0)
conMat[10,]<-c(0,0,0,1,-1,0,0,0,0,0,0,0,0,0,0)
rownames(conMat)=c("1-3","1-5","1-7","1-9","3-5","3-7","3-9","5-7","5-9","7-9")

estMat <- estimable(model5, conMat)
estMat



